[Cryptech-Commits] [core/util/keywrap] 54/95: Fixed minor details in unwrap test case. Enabled unwrap test case.

git at cryptech.is git at cryptech.is
Wed Mar 25 17:18:53 UTC 2020


This is an automated email from the git hooks/post-receive script.

paul at psgd.org pushed a commit to branch master
in repository core/util/keywrap.

commit 9897e1e85a8b3e0c61444da792522cc4f5a58534
Author: Joachim Strömbergson <joachim at secworks.se>
AuthorDate: Thu Jul 5 15:34:02 2018 +0200

    Fixed minor details in unwrap test case. Enabled unwrap test case.
---
 src/tb/tb_keywrap.v | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/tb/tb_keywrap.v b/src/tb/tb_keywrap.v
index b77a48c..545f031 100644
--- a/src/tb/tb_keywrap.v
+++ b/src/tb/tb_keywrap.v
@@ -496,7 +496,7 @@ module tb_keywrap();
       dump_mem(6);
 
 
       // Start wrapping and wait for wrap to complete.
       $display("* Trying to start processing.");
       write_word(ADDR_CTRL, 32'h00000002);
       #(2 * CLK_PERIOD);
@@ -504,7 +504,7 @@ module tb_keywrap();
       $display("* Processing should be done.");
 
 
-      $display("Contents of memory and dut after wrap processing:");
+      $display("Contents of memory and dut after unwrap processing:");
       dump_mem(6);
       dump_dut_state();
 
@@ -744,8 +744,8 @@ module tb_keywrap();
       reset_dut();
       dump_dut_state();
 
-      test_kwp_ae_128_1();
-//      test_kwp_ad_128_1();
+//      test_kwp_ae_128_1();
+      test_kwp_ad_128_1();
 //      test_kwp_ae_128_2();
 
       display_test_results();
@@ -496,7 +496,7 @@ module tb_keywrap();
 
 
-      // Start wrapping and wait for wrap to complete.
+      // Start unwrapping and wait for unwrap to complete.
       $display("* Trying to start processing.");
       write_word(ADDR_CTRL, 32'h00000002);



More information about the Commits mailing list